# eis-insurance
The EMIL InsuranceService API description

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0
- Package version: 1.23.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.emil.de](https://www.emil.de)

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install eis.insurance
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/emilDev/eis-insurance-sdk.git`)

Then import the package:
```python
import eis.insurance
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import eis.insurance
```

## Getting Started

The environment variables must be set in order to properly use this SDK.

```shell 
export EMIL_USERNAME=XXXXXXX
export EMIL_PASSWORD=XXXXXXX
```

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
import time
import eis.insurance
from pprint import pprint
from eis.insurance.api import insured_object_types_api
from eis.insurance.model.list_insured_object_types_response_class import ListInsuredObjectTypesResponseClass
# Defining the host is optional and defaults to https://apiv2.emil.de
# See configuration.py for a list of all supported configuration parameters.
configuration = eis.insurance.Configuration(
    host = "https://apiv2.emil.de"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Bearer is automatically handled with exported environment variables. However, you
# can manuallay configure Bearer authorization (JWT): bearer
configuration = eis.insurance.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)

# After manual token becomes invalid, the SDK will default to re-login automatically
# with environment variable credentials.


# Enter a context with an instance of the API client
with eis.insurance.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = insured_object_types_api.InsuredObjectTypesApi(api_client)
    authorization = "Authorization_example" # str | Bearer Token: provided by the login endpoint under the name accessToken. (optional)
    page_size = 3 # float | Page size. (optional)
    page_token = "2" # str | Page token. (optional)
    filter = "createdAt" # str | List filter (optional)
    search = "search_example" # str | Search query. (optional)
    order = "createdAt" # str | Ordering criteria. (optional)
    expand = "versions" # str | Extra fields to fetch. (optional)

    try:
        # List insured object types
        api_response = api_instance.list_insured_object_types(authorization=authorization, page_size=page_size, page_token=page_token, filter=filter, search=search, order=order, expand=expand)
        pprint(api_response)
    except eis.insurance.ApiException as e:
        print("Exception when calling InsuredObjectTypesApi->list_insured_object_types: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://apiv2.emil.de*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*InsuredObjectTypesApi* | [**list_insured_object_types**](docs/InsuredObjectTypesApi.md#list_insured_object_types) | **GET** /insuranceservice/v1/insured-object-types | List insured object types
*InsuredObjectsApi* | [**create_insured_object**](docs/InsuredObjectsApi.md#create_insured_object) | **POST** /insuranceservice/v1/insured-objects | Create the insured object
*InsuredObjectsApi* | [**delete_insured_object**](docs/InsuredObjectsApi.md#delete_insured_object) | **DELETE** /insuranceservice/v1/insured-objects/{id} | Delete the insured object
*InsuredObjectsApi* | [**get_insured_object**](docs/InsuredObjectsApi.md#get_insured_object) | **GET** /insuranceservice/v1/insured-objects/{id} | Retrieve the insured object
*InsuredObjectsApi* | [**list_insured_objects**](docs/InsuredObjectsApi.md#list_insured_objects) | **GET** /insuranceservice/v1/insured-objects | List insured objects
*LeadStatusesApi* | [**create_lead_status**](docs/LeadStatusesApi.md#create_lead_status) | **POST** /insuranceservice/v1/lead-statuses | Create the lead status
*LeadStatusesApi* | [**delete_lead_status**](docs/LeadStatusesApi.md#delete_lead_status) | **DELETE** /insuranceservice/v1/lead-statuses/{id} | Delete the lead status
*LeadStatusesApi* | [**get_lead_status**](docs/LeadStatusesApi.md#get_lead_status) | **GET** /insuranceservice/v1/lead-statuses/{id} | Retrieve the lead status
*LeadStatusesApi* | [**list_lead_statuses**](docs/LeadStatusesApi.md#list_lead_statuses) | **GET** /insuranceservice/v1/lead-statuses | List lead statuses
*LeadsApi* | [**create_lead**](docs/LeadsApi.md#create_lead) | **POST** /insuranceservice/v1/leads | Create the lead
*LeadsApi* | [**create_lead_async**](docs/LeadsApi.md#create_lead_async) | **POST** /insuranceservice/v1/leads-async | Create the lead asynchronously
*LeadsApi* | [**create_lead_sync**](docs/LeadsApi.md#create_lead_sync) | **POST** /insuranceservice/v1/leads-sync | Create the lead
*LeadsApi* | [**delete_lead**](docs/LeadsApi.md#delete_lead) | **DELETE** /insuranceservice/v1/leads/{code} | Delete the lead
*LeadsApi* | [**get_lead**](docs/LeadsApi.md#get_lead) | **GET** /insuranceservice/v1/leads/{code} | Retrieve the lead
*LeadsApi* | [**list_leads**](docs/LeadsApi.md#list_leads) | **GET** /insuranceservice/v1/leads | List leads
*LeadsApi* | [**patch_lead**](docs/LeadsApi.md#patch_lead) | **PATCH** /insuranceservice/v1/leads/{code} | Patch the lead
*LeadsApi* | [**update_lead**](docs/LeadsApi.md#update_lead) | **PUT** /insuranceservice/v1/leads/{code} | Update the lead
*LeadsApi* | [**update_lead_sync**](docs/LeadsApi.md#update_lead_sync) | **PUT** /insuranceservice/v1/leads-sync/{code} | Update the lead
*NamedRangesApi* | [**create_named_range**](docs/NamedRangesApi.md#create_named_range) | **POST** /insuranceservice/v1/named-ranges | Create the named range 
*NamedRangesApi* | [**delete_named_range**](docs/NamedRangesApi.md#delete_named_range) | **DELETE** /insuranceservice/v1/named-ranges/{id} | Delete the named range
*NamedRangesApi* | [**get_named_range**](docs/NamedRangesApi.md#get_named_range) | **GET** /insuranceservice/v1/named-ranges/{id} | Retrieve the named range
*NamedRangesApi* | [**list_named_ranges**](docs/NamedRangesApi.md#list_named_ranges) | **GET** /insuranceservice/v1/named-ranges | List named ranges
*NamedRangesApi* | [**update_named_range**](docs/NamedRangesApi.md#update_named_range) | **PUT** /insuranceservice/v1/named-ranges/{id} | Update the named range
*PoliciesApi* | [**activate_policy**](docs/PoliciesApi.md#activate_policy) | **POST** /insuranceservice/v1/policies/{policyCode}/activate | Activate a suspended policy by tenant
*PoliciesApi* | [**create_policy**](docs/PoliciesApi.md#create_policy) | **POST** /insuranceservice/v1/policies | Create the policy
*PoliciesApi* | [**get_policy**](docs/PoliciesApi.md#get_policy) | **GET** /insuranceservice/v1/policies/{code} | Retrieve the policy
*PoliciesApi* | [**get_policy_data_by_date**](docs/PoliciesApi.md#get_policy_data_by_date) | **GET** /insuranceservice/v1/policies/{code}/current-version | Retrieve current policy version
*PoliciesApi* | [**list_policies**](docs/PoliciesApi.md#list_policies) | **GET** /insuranceservice/v1/policies | List policies
*PoliciesApi* | [**suspend_policy**](docs/PoliciesApi.md#suspend_policy) | **POST** /insuranceservice/v1/policies/{policyCode}/suspend | Suspend a policy by tenant
*PoliciesApi* | [**terminate_policy**](docs/PoliciesApi.md#terminate_policy) | **POST** /insuranceservice/v1/policies/{policyCode}/terminate | Terminate a policy by tenant
*PoliciesApi* | [**update_policy**](docs/PoliciesApi.md#update_policy) | **PUT** /insuranceservice/v1/policies/{code} | Update the policy
*PoliciesApi* | [**withdraw_policy**](docs/PoliciesApi.md#withdraw_policy) | **POST** /insuranceservice/v1/policies/{policyCode}/withdraw | Withdraw policy by tenant
*PremiumFormulasApi* | [**create_premium_formula**](docs/PremiumFormulasApi.md#create_premium_formula) | **POST** /insuranceservice/v1/premium-formulas | Create the premium formula 
*PremiumFormulasApi* | [**delete_premium_formula**](docs/PremiumFormulasApi.md#delete_premium_formula) | **DELETE** /insuranceservice/v1/premium-formulas/{id} | Delete the premium formula
*PremiumFormulasApi* | [**get_premium_formula**](docs/PremiumFormulasApi.md#get_premium_formula) | **GET** /insuranceservice/v1/premium-formulas/{id} | Retrieve the premium formula
*PremiumFormulasApi* | [**list_premium_formulas**](docs/PremiumFormulasApi.md#list_premium_formulas) | **GET** /insuranceservice/v1/premium-formulas | List premium formulas
*PremiumFormulasApi* | [**swap_premium_formulas_order**](docs/PremiumFormulasApi.md#swap_premium_formulas_order) | **POST** /insuranceservice/v1/premium-formulas/reorder | Swaps premium formulas order
*PremiumFormulasApi* | [**update_premium_formula**](docs/PremiumFormulasApi.md#update_premium_formula) | **PUT** /insuranceservice/v1/premium-formulas/{id} | Update the premium formula
*ProductFactorsApi* | [**get_product_factor**](docs/ProductFactorsApi.md#get_product_factor) | **GET** /insuranceservice/v1/product-factors/{id} | Retrieve the product factor
*ProductFactorsApi* | [**get_product_factor_value**](docs/ProductFactorsApi.md#get_product_factor_value) | **GET** /insuranceservice/v1/product-factors/values | Get product factor value
*ProductFactorsApi* | [**get_product_factors_for_version**](docs/ProductFactorsApi.md#get_product_factors_for_version) | **GET** /insuranceservice/v1/product-factors/for-version | List product factors for version
*ProductFactorsApi* | [**list_product_factors**](docs/ProductFactorsApi.md#list_product_factors) | **GET** /insuranceservice/v1/product-factors | List product factors
*ProductFactorsApi* | [**store_product_factors**](docs/ProductFactorsApi.md#store_product_factors) | **POST** /insuranceservice/v1/product-factors | Upload product factors
*ProductFactorsApi* | [**validate_product_factors**](docs/ProductFactorsApi.md#validate_product_factors) | **POST** /insuranceservice/v1/product-factors/validate | Validate product factors
*ProductFieldsApi* | [**create_product_field**](docs/ProductFieldsApi.md#create_product_field) | **POST** /insuranceservice/v1/product-fields | Create the product field
*ProductFieldsApi* | [**delete_product_field**](docs/ProductFieldsApi.md#delete_product_field) | **DELETE** /insuranceservice/v1/product-fields/{id} | Delete the product
*ProductFieldsApi* | [**get_product_field**](docs/ProductFieldsApi.md#get_product_field) | **GET** /insuranceservice/v1/product-fields/{id} | Retrieve the product field
*ProductFieldsApi* | [**list_product_field_types**](docs/ProductFieldsApi.md#list_product_field_types) | **GET** /insuranceservice/v1/product-fields/types | List product field types
*ProductFieldsApi* | [**list_product_fields**](docs/ProductFieldsApi.md#list_product_fields) | **GET** /insuranceservice/v1/product-fields | List product fields
*ProductFieldsApi* | [**update_product_field**](docs/ProductFieldsApi.md#update_product_field) | **PUT** /insuranceservice/v1/product-fields/{id} | Update the product
*ProductVersionsApi* | [**get_product_version**](docs/ProductVersionsApi.md#get_product_version) | **GET** /insuranceservice/v1/product-versions/{id} | Retrieve the product version
*ProductVersionsApi* | [**update_product_version**](docs/ProductVersionsApi.md#update_product_version) | **PUT** /insuranceservice/v1/product-versions/{id} | Update the product version
*ProductsApi* | [**create_product**](docs/ProductsApi.md#create_product) | **POST** /insuranceservice/v1/products | Create the product
*ProductsApi* | [**delete_product**](docs/ProductsApi.md#delete_product) | **DELETE** /insuranceservice/v1/products/{id} | Delete the product
*ProductsApi* | [**get_product_by_code**](docs/ProductsApi.md#get_product_by_code) | **GET** /insuranceservice/v1/products/code/{code} | Retrieve the product
*ProductsApi* | [**get_product_by_identifier**](docs/ProductsApi.md#get_product_by_identifier) | **GET** /insuranceservice/v1/products/get-by-identifier | Retrieve the product
*ProductsApi* | [**list_products**](docs/ProductsApi.md#list_products) | **GET** /insuranceservice/v1/products | List products
*ProductsApi* | [**update_product**](docs/ProductsApi.md#update_product) | **PUT** /insuranceservice/v1/products/{id} | Update the product
*DefaultApi* | [**check**](docs/DefaultApi.md#check) | **GET** /insuranceservice/health | 


## Documentation For Models

 - [ActivatePolicyRequestDto](docs/ActivatePolicyRequestDto.md)
 - [ActivatePolicyResponseClass](docs/ActivatePolicyResponseClass.md)
 - [CalculateCustomPremiumRequestDto](docs/CalculateCustomPremiumRequestDto.md)
 - [CalculatePremiumRequestDto](docs/CalculatePremiumRequestDto.md)
 - [CloneProductVersionRequestDto](docs/CloneProductVersionRequestDto.md)
 - [CreateAccountRequestDto](docs/CreateAccountRequestDto.md)
 - [CreateBankAccountRequestDto](docs/CreateBankAccountRequestDto.md)
 - [CreateCustomApplicationRequestDto](docs/CreateCustomApplicationRequestDto.md)
 - [CreateDummyPolicyRequestDto](docs/CreateDummyPolicyRequestDto.md)
 - [CreateInsuredObjectRequestDto](docs/CreateInsuredObjectRequestDto.md)
 - [CreateInsuredObjectResponseClass](docs/CreateInsuredObjectResponseClass.md)
 - [CreateLeadAsyncResponseClass](docs/CreateLeadAsyncResponseClass.md)
 - [CreateLeadPolicyRequestDto](docs/CreateLeadPolicyRequestDto.md)
 - [CreateLeadRequestDto](docs/CreateLeadRequestDto.md)
 - [CreateLeadResponseClass](docs/CreateLeadResponseClass.md)
 - [CreateLeadStatusRequestDto](docs/CreateLeadStatusRequestDto.md)
 - [CreateLeadStatusResponseClass](docs/CreateLeadStatusResponseClass.md)
 - [CreateNamedRangeRequestDto](docs/CreateNamedRangeRequestDto.md)
 - [CreateNamedRangeResponseClass](docs/CreateNamedRangeResponseClass.md)
 - [CreateNamedRequestS3DataClass](docs/CreateNamedRequestS3DataClass.md)
 - [CreatePaymentMethodRequestDto](docs/CreatePaymentMethodRequestDto.md)
 - [CreatePolicyRequestDto](docs/CreatePolicyRequestDto.md)
 - [CreatePolicyResponseClass](docs/CreatePolicyResponseClass.md)
 - [CreatePremiumFormulaRequestDto](docs/CreatePremiumFormulaRequestDto.md)
 - [CreatePremiumFormulaResponseClass](docs/CreatePremiumFormulaResponseClass.md)
 - [CreateProductFieldRequestDto](docs/CreateProductFieldRequestDto.md)
 - [CreateProductFieldResponseClass](docs/CreateProductFieldResponseClass.md)
 - [CreateProductRequestDto](docs/CreateProductRequestDto.md)
 - [CreateProductResponseClass](docs/CreateProductResponseClass.md)
 - [CsvProductFactorDto](docs/CsvProductFactorDto.md)
 - [DeleteRequestDto](docs/DeleteRequestDto.md)
 - [DeleteResponseClass](docs/DeleteResponseClass.md)
 - [EmptyResponseClass](docs/EmptyResponseClass.md)
 - [GetInsuredObjectResponseClass](docs/GetInsuredObjectResponseClass.md)
 - [GetLeadResponseClass](docs/GetLeadResponseClass.md)
 - [GetLeadStatusResponseClass](docs/GetLeadStatusResponseClass.md)
 - [GetNamedRangeResponseClass](docs/GetNamedRangeResponseClass.md)
 - [GetPolicyDataByDateRequestDto](docs/GetPolicyDataByDateRequestDto.md)
 - [GetPolicyRequestDto](docs/GetPolicyRequestDto.md)
 - [GetPolicyResponseClass](docs/GetPolicyResponseClass.md)
 - [GetPremiumFormulaRequestDto](docs/GetPremiumFormulaRequestDto.md)
 - [GetPremiumFormulaResponseClass](docs/GetPremiumFormulaResponseClass.md)
 - [GetProductFactorResponseClass](docs/GetProductFactorResponseClass.md)
 - [GetProductFactorValueRequestDto](docs/GetProductFactorValueRequestDto.md)
 - [GetProductFactorValueResponseClass](docs/GetProductFactorValueResponseClass.md)
 - [GetProductFactorsForVersionRequestDto](docs/GetProductFactorsForVersionRequestDto.md)
 - [GetProductFactorsForVersionResponseClass](docs/GetProductFactorsForVersionResponseClass.md)
 - [GetProductFieldRequestDto](docs/GetProductFieldRequestDto.md)
 - [GetProductFieldResponseClass](docs/GetProductFieldResponseClass.md)
 - [GetProductRequestDto](docs/GetProductRequestDto.md)
 - [GetProductResponseClass](docs/GetProductResponseClass.md)
 - [GetProductVersionRequestDto](docs/GetProductVersionRequestDto.md)
 - [GetProductVersionResponseClass](docs/GetProductVersionResponseClass.md)
 - [GroupedProductFactorClass](docs/GroupedProductFactorClass.md)
 - [GroupedProductFactorValueClass](docs/GroupedProductFactorValueClass.md)
 - [GroupedProductFactorsResponseClass](docs/GroupedProductFactorsResponseClass.md)
 - [GrpcPatchLeadRequestDto](docs/GrpcPatchLeadRequestDto.md)
 - [GrpcUpdateLeadRequestDto](docs/GrpcUpdateLeadRequestDto.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse503](docs/InlineResponse503.md)
 - [InsuredObjectClass](docs/InsuredObjectClass.md)
 - [InsuredObjectTypeClass](docs/InsuredObjectTypeClass.md)
 - [InvoiceItemClass](docs/InvoiceItemClass.md)
 - [InvoiceStatusClass](docs/InvoiceStatusClass.md)
 - [LeadBankAccountClass](docs/LeadBankAccountClass.md)
 - [LeadClass](docs/LeadClass.md)
 - [LeadStatusClass](docs/LeadStatusClass.md)
 - [ListInsuredObjectTypesResponseClass](docs/ListInsuredObjectTypesResponseClass.md)
 - [ListInsuredObjectsResponseClass](docs/ListInsuredObjectsResponseClass.md)
 - [ListLeadStatusesResponseClass](docs/ListLeadStatusesResponseClass.md)
 - [ListLeadsResponseClass](docs/ListLeadsResponseClass.md)
 - [ListNamedRangesResponseClass](docs/ListNamedRangesResponseClass.md)
 - [ListPoliciesResponseClass](docs/ListPoliciesResponseClass.md)
 - [ListPremiumFormulasResponseClass](docs/ListPremiumFormulasResponseClass.md)
 - [ListProductFactorsResponseClass](docs/ListProductFactorsResponseClass.md)
 - [ListProductFieldTypesResponseClass](docs/ListProductFieldTypesResponseClass.md)
 - [ListProductFieldsResponseClass](docs/ListProductFieldsResponseClass.md)
 - [ListProductsResponseClass](docs/ListProductsResponseClass.md)
 - [ListRequestDto](docs/ListRequestDto.md)
 - [NamedRangeClass](docs/NamedRangeClass.md)
 - [PatchLeadRequestDto](docs/PatchLeadRequestDto.md)
 - [PatchLeadResponseClass](docs/PatchLeadResponseClass.md)
 - [PolicyClass](docs/PolicyClass.md)
 - [PolicyObjectClass](docs/PolicyObjectClass.md)
 - [PolicyObjectDto](docs/PolicyObjectDto.md)
 - [PolicyPremiumClass](docs/PolicyPremiumClass.md)
 - [PolicyPremiumItemClass](docs/PolicyPremiumItemClass.md)
 - [PolicyVersionClass](docs/PolicyVersionClass.md)
 - [PremiumFormulaClass](docs/PremiumFormulaClass.md)
 - [PremiumOverrideDto](docs/PremiumOverrideDto.md)
 - [PremiumOverrideRequestClass](docs/PremiumOverrideRequestClass.md)
 - [PremiumOverrideRequestDto](docs/PremiumOverrideRequestDto.md)
 - [ProductClass](docs/ProductClass.md)
 - [ProductFactorClass](docs/ProductFactorClass.md)
 - [ProductFactorForVersionClass](docs/ProductFactorForVersionClass.md)
 - [ProductFactorValueClass](docs/ProductFactorValueClass.md)
 - [ProductFactorValueForVersionClass](docs/ProductFactorValueForVersionClass.md)
 - [ProductFieldClass](docs/ProductFieldClass.md)
 - [ProductFieldTypeClass](docs/ProductFieldTypeClass.md)
 - [ProductVersionClass](docs/ProductVersionClass.md)
 - [SepaDto](docs/SepaDto.md)
 - [SharedCreateLeadPolicyRequestDto](docs/SharedCreateLeadPolicyRequestDto.md)
 - [SharedInvoiceClass](docs/SharedInvoiceClass.md)
 - [SharedLeadPolicyObjectDto](docs/SharedLeadPolicyObjectDto.md)
 - [SharedProductFieldClass](docs/SharedProductFieldClass.md)
 - [SharedUpdateNamedRangeRequestDto](docs/SharedUpdateNamedRangeRequestDto.md)
 - [SharedUpdatePremiumFormulaRequestDto](docs/SharedUpdatePremiumFormulaRequestDto.md)
 - [StoreProductFactorsRequestDto](docs/StoreProductFactorsRequestDto.md)
 - [StoreProductFactorsResponseClass](docs/StoreProductFactorsResponseClass.md)
 - [SuspendPolicyRequestDto](docs/SuspendPolicyRequestDto.md)
 - [SuspendPolicyResponseClass](docs/SuspendPolicyResponseClass.md)
 - [SwapPremiumFormulasOrderRequestDto](docs/SwapPremiumFormulasOrderRequestDto.md)
 - [TerminatePolicyRequestDto](docs/TerminatePolicyRequestDto.md)
 - [TerminatePolicyResponseClass](docs/TerminatePolicyResponseClass.md)
 - [TimesliceClass](docs/TimesliceClass.md)
 - [UpdateInsuredObjectRequestDto](docs/UpdateInsuredObjectRequestDto.md)
 - [UpdateLeadRequestDto](docs/UpdateLeadRequestDto.md)
 - [UpdateLeadResponseClass](docs/UpdateLeadResponseClass.md)
 - [UpdateNamedRangeRequestDto](docs/UpdateNamedRangeRequestDto.md)
 - [UpdateNamedRangeResponseClass](docs/UpdateNamedRangeResponseClass.md)
 - [UpdatePolicyRequestDto](docs/UpdatePolicyRequestDto.md)
 - [UpdatePolicyResponseClass](docs/UpdatePolicyResponseClass.md)
 - [UpdatePremiumFormulaRequestDto](docs/UpdatePremiumFormulaRequestDto.md)
 - [UpdatePremiumFormulaResponseClass](docs/UpdatePremiumFormulaResponseClass.md)
 - [UpdateProductFieldRequestDto](docs/UpdateProductFieldRequestDto.md)
 - [UpdateProductFieldResponseClass](docs/UpdateProductFieldResponseClass.md)
 - [UpdateProductRequestDto](docs/UpdateProductRequestDto.md)
 - [UpdateProductResponseClass](docs/UpdateProductResponseClass.md)
 - [UpdateProductVersionRequestDto](docs/UpdateProductVersionRequestDto.md)
 - [UpdateProductVersionResponseClass](docs/UpdateProductVersionResponseClass.md)
 - [UploadedDocumentDto](docs/UploadedDocumentDto.md)
 - [ValidateProductFactorsRequestDto](docs/ValidateProductFactorsRequestDto.md)
 - [WithdrawPolicyResponseClass](docs/WithdrawPolicyResponseClass.md)


## Documentation For Authorization


## bearer

- **Type**: Bearer authentication (JWT)


## Author

kontakt@emil.de


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in eis.insurance.apis and eis.insurance.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from eis.insurance.api.default_api import DefaultApi`
- `from eis.insurance.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import eis.insurance
from eis.insurance.apis import *
from eis.insurance.models import *
```

